/*
 * Copyright 2010-2013 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */




/**
 * Assumed Role User
 */

@interface SecurityTokenServiceAssumedRoleUser:NSObject

{
    NSString *assumedRoleId;
    NSString *arn;
}




/**
 * Default constructor for a new  object.  Callers should use the
 * property methods to initialize this object after creating it.
 */
-(id)init;

/**
 * A unique identifier that contains the role ID and the role session
 * name of the role that is being assumed. The role ID is generated by
 * AWS when the role is created.
 * <p>
 * <b>Constraints:</b><br/>
 * <b>Length: </b>2 - 96<br/>
 * <b>Pattern: </b>[\w+=,.@:-]*<br/>
 */
@property (nonatomic, retain) NSString *assumedRoleId;

/**
 * The ARN of the temporary security credentials that are returned from
 * the <a>AssumeRole</a> action. For more information about ARNs and how
 * to use them in policies, see <a
 * ttp://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html"
 * target="_blank"> Identifiers for IAM Entities </a> in <i>Using
 * IAM</i>.
 * <p>
 * <b>Constraints:</b><br/>
 * <b>Length: </b>20 - 2048<br/>
 */
@property (nonatomic, retain) NSString *arn;

/**
 * Returns a string representation of this object; useful for testing and
 * debugging.
 *
 * @return A string representation of this object.
 */
-(NSString *)description;


@end
